# Generated by Django 4.1.7 on 2023-05-18 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('capeditor', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alertinfo',
            name='language',
            field=models.CharField(blank=True, choices=[('en', 'English'), ('fr', 'French'), ('ar', 'Arabic'), ('am', 'Amharic'), ('sw', 'Swahili')], default='en', help_text='The code denoting the language of the alert message', max_length=100, null=True, verbose_name='Language'),
        ),
    ]



import os
import uuid

from setuptools import find_packages
from distutils.core import setup

try: # for pip >= 10
    from pip._internal.req import parse_requirements
except ImportError: # for pip <= 9.0.3
    from pip.req import parse_requirements


PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))


with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), 'README.md')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

# parse_requirements() returns generator of pip.req.InstallRequirement objects
install_requirements = parse_requirements(os.path.join(PROJECT_ROOT, 'requirements.txt'), session=uuid.uuid1())

# e.g. ['django', 'google-api-python-client']
requirements = [getattr(ir, 'requirement', str(getattr(ir, 'req', None))) for ir in install_requirements]

setup(
    name='capeditor',
    version='0.1.9',
    packages=find_packages(),
    install_requires=requirements,
    include_package_data=True,
    license='MIT License',
    description='Wagtail CAP Editor can be run as standalone or integrated into website',
    long_description=README,
    long_description_content_type='text/markdown',
    url='https://github.com/wmo-raf/cap-editor',
    author='Grace Amondi',
    author_email='miswa.grace@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)



# Generated by Django 4.1.7 on 2023-06-19 12:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('capeditor', '0002_alter_alertinfo_language'),
    ]

    operations = [
        migrations.AlterField(
            model_name='alert',
            name='sender',
            field=models.EmailField(help_text=' Identifies the originator of an alert. This can be an email of the institution for example', max_length=255, verbose_name='Sender'),
        ),
    ]
